@@ -314,9 +314,18 @@ class SmokeTestResults(Document):
 
 class CrawlerHistory(Document):
     """ Crawler History  """
-    sysetm = StringField(max_length=120, required=True)
     timestamp = DateTimeField(required=True)
     url = StringField(required=True)
+    sysetm = StringField(max_length=120)
     run_time = FloatField()
     number_of_events = IntField()
-    logs = StringField(max_length=10000)
\ No newline at end of file
+    logs = StringField(max_length=10000)
+    result = StringField(max_length=50)
+
+class SystemInDB(Document):
+    """ System from setting page  """
+    url = StringField(max_length=120, required=True)
+    name = StringField(required=True)
+    system_type = StringField(required=True)
+    is_active = BooleanField(required=True)
+    encrypted_password = StringField(required=True)
\ No newline at end of file
