@@ -18,7 +18,7 @@ class MongoSettings():
         self.mongo_host = host if host is not None else os.environ.get("MONGO_HOST", "host.docker.internal")
         self.mongo_db = db_name if db_name is not None else os.environ.get("MONGO_DB", "topograph")
         self.host = f"mongodb://{self.mongo_host}:{self.mongo_port}"
-        self.client = connect(self.mongo_db, host=self.host, port=self.mongo_port, connect=False)
+        self.client = connect(self.mongo_db, host=self.host, port=self.mongo_port, alias='default', connect=False)
 
     def connect(self):
         return self.client
